summaryrefslogtreecommitdiff
path: root/TAO/tao/MProfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tao/MProfile.h')
-rw-r--r--TAO/tao/MProfile.h16
1 files changed, 14 insertions, 2 deletions
diff --git a/TAO/tao/MProfile.h b/TAO/tao/MProfile.h
index 5222d785c63..13de8fa3330 100644
--- a/TAO/tao/MProfile.h
+++ b/TAO/tao/MProfile.h
@@ -62,12 +62,18 @@ public:
// profiles!
int set (CORBA::ULong sz);
- // @@ Fred, what does this method do?
+ // Inits MProfile to hold sz TAO_Profiles.
+ // NOT THREAD SAFE
int set (const TAO_MProfile &mprofile);
// Inits this to the values of mprofile. NOTE: We use
// mprofile->last_ instead of mprofile->size_ to set this->size_.
// This is so we can use set () to trim a profile list!!
+ // NOT THREAD SAFE
+
+ int grow (CORBA::ULong sz);
+ // increate the number of profiles this object can hold.
+ // NOT THREAD SAFE
TAO_Profile_ptr get_cnext (void);
// Treat as a circular list.
@@ -94,7 +100,11 @@ public:
// Returns the index for the current profile.
CORBA::ULong profile_count (void) const;
- // Returns the number of profiles stored in the list (last_).
+ // Returns the number of profiles stored in the list (last_+1).
+
+ CORBA::ULong size (void) const;
+ // return the maximum number of profiles that can be stored in this
+ // container, (size_+1)
const TAO_Profile* get_profile (CORBA::ULong index) const;
// Return the profile at position <index>.
@@ -127,6 +137,8 @@ public:
CORBA::ULong hash (CORBA::ULong max,
CORBA::Environment &env);
+ // use all registered profiles. The hash() method is called on each
+ // profile and the results are averaged together.
// @@ FRED: The list should be locked for this!
protected: